package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ZyRecruit;
import com.ruoyi.system.service.IZyRecruitService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 人才招聘信息Controller
 * 
 * @author libao
 * @date 2024-05-24
 */
@RestController
@RequestMapping("/system/recruit")
public class ZyRecruitController extends BaseController
{
    @Autowired
    private IZyRecruitService zyRecruitService;

    /**
     * 查询人才招聘信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:recruit:list')")
    @GetMapping("/list")
    public TableDataInfo list(ZyRecruit zyRecruit)
    {
        startPage();
        List<ZyRecruit> list = zyRecruitService.selectZyRecruitList(zyRecruit);
        return getDataTable(list);
    }

    /**
     * 导出人才招聘信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:recruit:export')")
    @Log(title = "人才招聘信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ZyRecruit zyRecruit)
    {
        List<ZyRecruit> list = zyRecruitService.selectZyRecruitList(zyRecruit);
        ExcelUtil<ZyRecruit> util = new ExcelUtil<ZyRecruit>(ZyRecruit.class);
        util.exportExcel(response, list, "人才招聘信息数据");
    }

    /**
     * 获取人才招聘信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:recruit:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(zyRecruitService.selectZyRecruitById(id));
    }

    /**
     * 新增人才招聘信息
     */
    @PreAuthorize("@ss.hasPermi('system:recruit:add')")
    @Log(title = "人才招聘信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ZyRecruit zyRecruit)
    {
        return toAjax(zyRecruitService.insertZyRecruit(zyRecruit));
    }

    /**
     * 修改人才招聘信息
     */
    @PreAuthorize("@ss.hasPermi('system:recruit:edit')")
    @Log(title = "人才招聘信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ZyRecruit zyRecruit)
    {
        return toAjax(zyRecruitService.updateZyRecruit(zyRecruit));
    }

    /**
     * 删除人才招聘信息
     */
    @PreAuthorize("@ss.hasPermi('system:recruit:remove')")
    @Log(title = "人才招聘信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(zyRecruitService.deleteZyRecruitByIds(ids));
    }
}
